# main developer:   
Core routines, code structure and working examples.

#### Kai Trepte, PhD  
email: kai.trepte1987@gmail.edu
- all main FORTRAN routines

#### Sebastian Schwalbe, M. Sc.  
email: theonov13@gmail.com
- GUI for porE
- source code structuring
- ideas for improvements of porE (simplification of input)
